/*
 * Copyright (C) 2005-2009 Makoto Sato. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.objectfanatics.assertion.weaver.api.exception.info;

import jp.objectfanatics.assertion.weaver.api.exception.LineNumberNotAvailableException;
import jp.objectfanatics.assertion.weaver.api.exception.info.TypeInfo.PackageNotFoundException;

//Checked 09.26.2009. Delete this line before release.
/**
 * Behavior information.
 * 
 * @author Makoto Sato
 */
public interface BehaviorInfo {
	
	/**
	 * Returns line number.
	 * 
	 * @return line number
	 * @throws LineNumberNotAvailableException
	 *             if line number is not available
	 */
	int getLineNumber() throws LineNumberNotAvailableException;
	
	/**
	 * Returns long name.
	 * 
	 * @return long name
	 */
	String getLongName();
	
	/**
	 * Returns declaring type information.
	 * 
	 * @return declaring type information
	 */
	TypeInfo getDeclaringType();
	
	/**
	 * Short cut method : this.getDeclaringType().getSourceFileName().
	 */
	String getSourceFileName();
	
	/**
	 * Short cut method : this.getDeclaringType().getPackageName().
	 */
	String getPackageName() throws PackageNotFoundException;
}
