/*
 * Copyright (C) 2005-2009 Makoto Sato. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.objectfanatics.assertion.weaver.impl.constraint;

import jp.objectfanatics.assertion.weaver.impl.core.ConstraintAnnotationAssertionWeaver;

// TODO: 各Weaverは、状態を持たせない前提が成り立つなら、プライベートコンストラクタ＆Singletonでよいのでは？ 継承は重要なので static にはしないけど。
/**
 * Abstract class for {@link ConstraintAnnotationAssertionWeaver}.
 * 
 * @author Makoto Sato
 */
abstract public class AbstractAssertionWeaver implements ConstraintAnnotationAssertionWeaver {
	
	/**
	 * Target constraint annotation class.
	 */
	protected final Class<? extends java.lang.annotation.Annotation> targetConstraintAnnotation;
	
	/**
	 * Initializes a newly created <code>AbstractAssertionWeaver</code> object with <code>targetConstraintAnnotation</code>.
	 * 
	 * @param targetConstraintAnnotation
	 */
	public AbstractAssertionWeaver(Class<? extends java.lang.annotation.Annotation> targetConstraintAnnotation) {
		this.targetConstraintAnnotation = targetConstraintAnnotation;
	}
	
	@Override
	public Class<? extends java.lang.annotation.Annotation> getTargetConstraintAnnotation() {
		return targetConstraintAnnotation;
	}
	
	/**
	 * Generates assertion statement string.
	 * 
	 * @param assertionErrorCondition
	 * @param message
	 * @return assertion statement string
	 */
	protected final String generateParameterAssrtionStatement(String assertionErrorCondition, String message) {
		return generateAssrtionStatement(assertionErrorCondition, message, IllegalArgumentException.class.getSimpleName());
	}
	
	/**
	 * Generates assertion statement string.
	 * 
	 * @param assertionErrorCondition
	 * @param message
	 * @return assertion statement string
	 */
	protected final String generateReturnValueAssrtionStatement(String assertionErrorCondition, String message) {
		return generateAssrtionStatement(assertionErrorCondition, message, IllegalStateException.class.getSimpleName());
	}
	
	/**
	 * Generates assertion statement string.
	 * 
	 * @param assertionErrorCondition
	 * @param message
	 * @return assertion statement string
	 */
	private final String generateAssrtionStatement(String assertionErrorCondition, String message, String exceptionName) {
		// using a constructor of AssertionError because assert statement is not supported by javassist
		return "if (" + assertionErrorCondition + ") throw new " + exceptionName + "(\"" + message + "\");";
	}
}
