/*
 * Copyright (C) 2005-2009 Makoto Sato. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.objectfanatics.assertion.weaver.impl.exception.info;

import javassist.CtClass;
import jp.objectfanatics.assertion.weaver.api.exception.info.TypeInfo;
import jp.objectfanatics.commons.javassist.JavassistUtils;

//Checked 09.26.2009. Delete this line before release.
/**
 * An implementation class of {@link TypeInfo}.
 * 
 * @author Makoto Sato
 */
public class TypeInfoImpl implements TypeInfo {
	
	private final CtClass ctClass;
	
	/**
	 * Constructor.
	 * 
	 * @param ctClass
	 *            {@link CtClass}
	 * @throws IllegalArgumentException
	 *             if <code>ctClass</code> is <code>null</code>
	 */
	public TypeInfoImpl(CtClass ctClass) {
		if (ctClass == null) throw new IllegalArgumentException("ctClass is null.");
		this.ctClass = ctClass;
	}
	
	@Override
	public String getName() {
		return ctClass.getName();
	}
	
	@Override
	public String getSimpleName() {
		return ctClass.getSimpleName();
	}
	
	@Override
	public String getSourceFileName() {
		return JavassistUtils.getSourceFileName(ctClass);
	}
	
	@Override
	public String getPackageName() throws PackageNotFoundException {
		String packageName = ctClass.getPackageName();
		if (packageName == null) throw new PackageNotFoundException();
		return packageName;
	}
}
